#!/bin/bash

set -e

function usage() {
    echo "usage: $0 [options] machine-name"
    echo "
Required environment:

export OS_AUTH_URL=
export OS_TENANT_ID=
export OS_TENANT_NAME=
export OS_USERNAME=
export OS_PASSWORD=
export OS_REGION_NAME=
export TUTUM_USER=
export TUTUM_APIKEY=
"
    exit 1
}

TUTUM_TAGS=()
OPENSTACK_ARGS=()

while [[ $# > 0 ]]
do
    key="$1"

    # MACHINE_NAME should be the last argument.
    if [[ -n $MACHINE_NAME ]]; then usage; fi

    case $key in
        --tag)
            TUTUM_TAGS+=("--tag")
            TUTUM_TAGS+=("$2")
            TUTUM_SUMMARY="$TUTUM_SUMMARY/$2"
            shift
            ;;
        --openstack-*)
            OPENSTACK_ARGS+=("$key")
            OPENSTACK_ARGS+=("$2")
            OPENSTACK_SUMMARY="$OPENSTACK_SUMMARY/$2"
            shift
            ;;
        --default)
            DEFAULT=YES
            ;;
        -*)
            # unknown option
            echo "ERROR: unknown option: '$1'"
            usage
            ;;
        *)
            MACHINE_NAME=$1
            ;;
    esac
    shift
done

# MACHINE_NAME should be defined
if [[ ! -n $MACHINE_NAME ]]; then
    usage
fi

if [[ ! -n $TUTUM_APIKEY ]]; then
    usage
fi

echo
echo "  Machine: $MACHINE_NAME"
echo "Openstack: $OPENSTACK_SUMMARY"
echo "    Tutum: $TUTUM_SUMMARY"
echo

# Give some time to the user to think about what he is doing.
#sleep 4

# Create the machine.
docker-machine create --driver openstack "${OPENSTACK_ARGS[@]}" $MACHINE_NAME

# Provision the machine on tutum
docker-machine ssh $MACHINE_NAME "$(tutum node byo | grep curl)"

# Retrieve the docker-machine IP address
IP=$(docker-machine inspect $MACHINE_NAME | grep \"Ip\" | cut -d\" -f4)

# Find the machine on tutum from its IP address
TUTUM_NODES=$(tutum node list -q)
for node in $TUTUM_NODES; do
    if tutum node inspect $node | grep \"$IP\"; then

        # Found the machine
        echo "Node found on Tutum. Waiting for it to be ready..."
        while ! tutum node inspect $node | grep \"Deployed\"; do sleep 1; done

        # Tag it!
        tutum tag add -t $MACHINE_NAME "${TUTUM_TAGS[@]}" $node
        exit 0
    fi
done
